@@ -11,7 +11,7 @@
 #' imported with the \code{foreign} package.
 #' @seealso
 #' \code{\link{regex}}, \code{description} in the \code{memisc} package
-#' @author François Briatte <f.briatte@@ed.ac.uk>
+#' @author François Briatte <f.briatte@@gmail.com>
 #' @examples
 #' # Variables in a standard R data frame.
 #' data(hdv2003)
@@ -39,7 +39,7 @@ describe <- function(data, ...) {
   # memisc objects
   if(grepl("data.set|importer", class(data))) {
       suppressMessages(suppressWarnings(require(memisc)))
-      l <- description(data[, x])
+      l <- memisc::description(data[, x])
   }
   else {
     # foreign objects
